from cmk.gui.i18n import _
from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications
)
from cmk.gui.valuespec import (
    Dictionary,
    ListChoice,
    TextAscii,
    Percentage,
    Tuple,
    Float,
    Integer
)    

def _item_spec_mailcow_domains():
    return TextAscii(
        title=_("Domain name")
    )

def _parameter_spec_mailcow_domains():
    return Dictionary(
        elements=[
            ("levels_mailcow_domains_quota_used", Tuple(
                title=_("Mailcow domains quota usage for storage"),
                    elements=[
                        Percentage(
                            title=_("Warning at"),
                            default_value=65.0,
                        ),
                        Percentage(
                            title=_("Critical at"),
                            default_value=85.0,
                        )
                    ],
            )),
            ("levels_mailcow_domains_mailboxes_used", Tuple(
                title=_("Mailcow domains mailboxes usage"),
                    elements=[
                        Percentage(
                            title=_("Warning at"),
                            default_value=65.0,
                        ),
                        Percentage(
                            title=_("Critical at"),
                            default_value=85.0,
                        )
                    ],
            )),
            ("levels_mailcow_domains_aliases_used", Tuple(
                title=_("Mailcow domains aliases usage"),
                    elements=[
                        Percentage(
                            title=_("Warning at"),
                            default_value=65.0,
                        ),
                        Percentage(
                            title=_("Critical at"),
                            default_value=85.0,
                        )
                    ],
            )),
            ("levels_mailcow_domains_num_messages", Tuple(
                title=_("Number of messages"),
                    elements=[
                        Integer(
                            title=_("Warning at"),
                            default_value=10000,
                        ),
                        Integer(
                            title=_("Critical at"),
                            default_value=25000,
                        )
                    ],
            )),
            ("levels_mailcow_domains_num_aliases", Tuple(
                title=_("Number of configured aliases"),
                    elements=[
                        Integer(
                            title=_("Warning at"),
                            default_value=100,
                        ),
                        Integer(
                            title=_("Critical at"),
                            default_value=250,
                        )
                    ],
            )),
            ("levels_mailcow_domains_num_mailboxes", Tuple(
                title=_("Number of configured mailboxes"),
                    elements=[
                        Integer(
                            title=_("Warning at"),
                            default_value=100,
                        ),
                        Integer(
                            title=_("Critical at"),
                            default_value=250,
                        )
                    ],
            )),
        ],
    )

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="mailcow_domains",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        item_spec=_item_spec_mailcow_domains,
        parameter_valuespec=_parameter_spec_mailcow_domains,
        title=lambda: _("Levels for Mailcow domains"),
    )
)